==> openshift-model-monitoring-5.12.2-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/WeChatConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class WeChatConfigBuilder extends io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfig,io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigBuilder>{
  public WeChatConfigBuilder() {
    this(false);
  }
  public WeChatConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new WeChatConfig(), validationEnabled);
  }
  public WeChatConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public WeChatConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new WeChatConfig(), validationEnabled);
  }
  public WeChatConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfig instance) {
    this(fluent, instance, false);
  }
  public WeChatConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAgentID(instance.getAgentID()); 
    fluent.withApiSecret(instance.getApiSecret()); 
    fluent.withApiURL(instance.getApiURL()); 
    fluent.withCorpID(instance.getCorpID()); 
    fluent.withHttpConfig(instance.getHttpConfig()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withMessageType(instance.getMessageType()); 
    fluent.withSendResolved(instance.getSendResolved()); 
    fluent.withToParty(instance.getToParty()); 
    fluent.withToTag(instance.getToTag()); 
    fluent.withToUser(instance.getToUser()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public WeChatConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfig instance) {
    this(instance,false);
  }
  public WeChatConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAgentID(instance.getAgentID()); 
    this.withApiSecret(instance.getApiSecret()); 
    this.withApiURL(instance.getApiURL()); 
    this.withCorpID(instance.getCorpID()); 
    this.withHttpConfig(instance.getHttpConfig()); 
    this.withMessage(instance.getMessage()); 
    this.withMessageType(instance.getMessageType()); 
    this.withSendResolved(instance.getSendResolved()); 
    this.withToParty(instance.getToParty()); 
    this.withToTag(instance.getToTag()); 
    this.withToUser(instance.getToUser()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfig build() {
    WeChatConfig buildable = new WeChatConfig(fluent.getAgentID(),fluent.getApiSecret(),fluent.getApiURL(),fluent.getCorpID(),fluent.getHttpConfig(),fluent.getMessage(),fluent.getMessageType(),fluent.getSendResolved(),fluent.getToParty(),fluent.getToTag(),fluent.getToUser());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    WeChatConfigBuilder that = (WeChatConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-6.5.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/WeChatConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class WeChatConfigBuilder extends WeChatConfigFluentImpl<WeChatConfigBuilder> implements VisitableBuilder<WeChatConfig,WeChatConfigBuilder>{
  public WeChatConfigBuilder() {
    this(false);
  }
  public WeChatConfigBuilder(Boolean validationEnabled) {
    this(new WeChatConfig(), validationEnabled);
  }
  public WeChatConfigBuilder(WeChatConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public WeChatConfigBuilder(WeChatConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new WeChatConfig(), validationEnabled);
  }
  public WeChatConfigBuilder(WeChatConfigFluent<?> fluent,WeChatConfig instance) {
    this(fluent, instance, false);
  }
  public WeChatConfigBuilder(WeChatConfigFluent<?> fluent,WeChatConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAgentID(instance.getAgentID()); 
    fluent.withApiSecret(instance.getApiSecret()); 
    fluent.withApiURL(instance.getApiURL()); 
    fluent.withCorpID(instance.getCorpID()); 
    fluent.withHttpConfig(instance.getHttpConfig()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withMessageType(instance.getMessageType()); 
    fluent.withSendResolved(instance.getSendResolved()); 
    fluent.withToParty(instance.getToParty()); 
    fluent.withToTag(instance.getToTag()); 
    fluent.withToUser(instance.getToUser()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public WeChatConfigBuilder(WeChatConfig instance) {
    this(instance,false);
  }
  public WeChatConfigBuilder(WeChatConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAgentID(instance.getAgentID()); 
    this.withApiSecret(instance.getApiSecret()); 
    this.withApiURL(instance.getApiURL()); 
    this.withCorpID(instance.getCorpID()); 
    this.withHttpConfig(instance.getHttpConfig()); 
    this.withMessage(instance.getMessage()); 
    this.withMessageType(instance.getMessageType()); 
    this.withSendResolved(instance.getSendResolved()); 
    this.withToParty(instance.getToParty()); 
    this.withToTag(instance.getToTag()); 
    this.withToUser(instance.getToUser()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  WeChatConfigFluent<?> fluent;
  Boolean validationEnabled;
  public WeChatConfig build() {
    WeChatConfig buildable = new WeChatConfig(fluent.getAgentID(),fluent.getApiSecret(),fluent.getApiURL(),fluent.getCorpID(),fluent.getHttpConfig(),fluent.getMessage(),fluent.getMessageType(),fluent.getSendResolved(),fluent.getToParty(),fluent.getToTag(),fluent.getToUser());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
